==> haskell-wai-http2-extra-0.1.3-357-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-8xekZ9CTruEUjhldwUVtm
key:                  wai-http2-extra-0.1.3-8xekZ9CTruEUjhldwUVtm
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  9c2c4235eeec558fdadeb12276210b2a
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-8xekZ9CTruEUjhldwUVtm
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    psqueues-0.2.8.2-6HBRDQVmIk33mE0LOnQqk2
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG warp-3.3.31-EuVFpHL4tC8B6O3zETiGa1
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-http2-extra-0.1.3-358-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-JztWM5AjsI4DLP9ICEDjZ3
key:                  wai-http2-extra-0.1.3-JztWM5AjsI4DLP9ICEDjZ3
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  78d6f7fcbb2bbda2587f182aeb2b7b39
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-JztWM5AjsI4DLP9ICEDjZ3
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    psqueues-0.2.8.2-6HBRDQVmIk33mE0LOnQqk2
    wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG warp-3.4.0-LYdxDOwOJ3v4yktLABaOuj
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
